@@ -466,7 +466,8 @@ oO񍐁Apb`}܂B
 =item * m/$re/o, s/$re/foo/o, qr/$re/o  /o Cq
 
     perl5.006 ɂ /o CqҒʂ̓܂łBϐ $re ̒l
-    ύXƎ̎sɂ̕ύXf܂B
+    ύXƎ̎sɂ̕ύXf܂Bł /o gƂ $re
+    ̓eύXȂł傤AۂɖɂȂ邱Ƃ͂Ȃł傤B
 
 =item * K\̃GXP[v \b  \B
 
